# Pysmells

`pysmells` é uma ferramenta de análise de código Python que verifica a adoção de Type Annotations e fornece relatórios sobre alertas do Pylint e Mypy.

## Instalação

Você pode instalar o `pysmells` usando pip:

pip install pysmells

## Uso

Após a instalação, você pode usar o `pysmells` da seguinte maneira:

1. Navegue até o diretório do projeto que deseja analisar.
2. Execute `pysmells` no terminal.

O `pysmells` irá analisar todos os arquivos `.py` no diretório especificado e fornecerá um relatório detalhado com os resultados.

## Licença

Este projeto está licenciado sob a licença MIT - consulte o arquivo [LICENSE](LICENSE) para obter detalhes.
